Release Managed and Unlocked Packages
-------------------------------------

CumulusCI makes it easy to build first- and second-generation managed packages, as well as unlocked packages.
While the overall workflows for all types of packages are quite similar, there are key differences between them.
The chapters below explore all three packaging options.

New projects should, absent any other considerations, generally choose to use second-generation managed packages or
unlocked packages. Learn more about second-generation packaging and its advantages in the `Salesforce DX Developer Guide <https://developer.salesforce.com/docs/atlas.en-us.sfdx_dev.meta/sfdx_dev/sfdx_dev_dev2gp.htm>`_.

.. toctree::
   :maxdepth: 1

   managed_package.rst
   managed_2gp.rst
   unlocked_package.rst
   npsp_eda_2gp.rst
   release_notes.rst
   push_upgrades.rst
